@@ -8,3 +8,5 @@ from .SingScore import *
 from .tumor_deconvolve import tumor_deconvolve
 from .visualization import *
 from .hugoify import *
+from .batch_correction import *
+from .signature_matrix import *
